==> dojo_1.11.0+dfsg.orig.tar.gz: dojo-release-1.11.0-src/dojo/cldr/nls/sv/gregorian.js <==
define(
//begin v1.x content
{
	"dateFormatItem-Ehm": "E h:mm a",
	"days-standAlone-short": [
		"Sö",
		"Må",
		"Ti",
		"On",
		"To",
		"Fr",
		"Lö"
	],
	"months-format-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"field-second-relative+0": "nu",
	"quarters-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-weekday": "Veckodag",
	"dateFormatItem-yQQQ": "y QQQ",
	"dateFormatItem-yMEd": "E, y-MM-dd",
	"field-wed-relative+0": "onsdag denna vecka",
	"dateFormatItem-GyMMMEd": "E d MMM y G",
	"dateFormatItem-MMMEd": "E d MMM",
	"field-wed-relative+1": "onsdag nästa vecka",
	"eraNarrow": [
		"f.Kr.",
		"fvt",
		"e.Kr.",
		"vt"
	],
	"dateFormatItem-yMM": "y-MM",
	"field-tue-relative+-1": "tisdag förra veckan",
	"days-format-short": [
		"sö",
		"må",
		"ti",
		"on",
		"to",
		"fr",
		"lö"
	],
	"dateFormat-long": "d MMMM y",
	"field-fri-relative+-1": "fredag förra veckan",
	"field-wed-relative+-1": "onsdag förra veckan",
	"months-format-wide": [
		"januari",
		"februari",
		"mars",
		"april",
		"maj",
		"juni",
		"juli",
		"augusti",
		"september",
		"oktober",
		"november",
		"december"
	],
	"dateTimeFormat-medium": "{1} {0}",
	"dayPeriods-format-wide-pm": "em",
	"dateFormat-full": "EEEE d MMMM y",
	"field-thu-relative+-1": "torsdag förra veckan",
	"dateFormatItem-Md": "d/M",
	"dayPeriods-format-abbr-am": "FM",
	"dateFormatItem-yMd": "y-MM-dd",
	"dateFormatItem-yM": "y-MM",
	"field-era": "Era",
	"months-standAlone-wide": [
		"Januari",
		"Februari",
		"Mars",
		"April",
		"Maj",
		"Juni",
		"Juli",
		"Augusti",
		"September",
		"Oktober",
		"November",
		"December"
	],
	"timeFormat-short": "HH:mm",
	"quarters-format-wide": [
		"1:a kvartalet",
		"2:a kvartalet",
		"3:e kvartalet",
		"4:e kvartalet"
	],
	"timeFormat-long": "HH:mm:ss z",
	"dateFormatItem-yMMM": "MMM y",
	"dateFormatItem-yQQQQ": "y QQQQ",
	"field-year": "År",
	"dateFormatItem-MMdd": "dd/MM",
	"field-hour": "timme",
	"months-format-abbr": [
		"jan",
		"feb",
		"mar",
		"apr",
		"maj",
		"jun",
		"jul",
		"aug",
		"sep",
		"okt",
		"nov",
		"dec"
	],
	"field-sat-relative+0": "lördag denna vecka",
	"field-sat-relative+1": "lördag nästa vecka",
	"timeFormat-full": "'kl'. HH:mm:ss zzzz",
	"field-day-relative+0": "i dag",
	"field-day-relative+1": "i morgon",
	"field-thu-relative+0": "torsdag denna vecka",
	"dateFormatItem-GyMMMd": "d MMM y G",
	"field-day-relative+2": "i övermorgon",
	"field-thu-relative+1": "torsdag nästa vecka",
	"dateFormatItem-H": "HH",
	"months-standAlone-abbr": [
		"Jan",
		"Feb",
		"Mar",
		"Apr",
		"Maj",
		"Jun",
		"Jul",
		"Aug",
		"Sep",
		"Okt",
		"Nov",
		"Dec"
	],
	"quarters-format-abbr": [
		"K1",
		"K2",
		"K3",
		"K4"
	],
	"quarters-standAlone-wide": [
		"1:a kvartalet",
		"2:a kvartalet",
		"3:e kvartalet",
		"4:e kvartalet"
	],
	"dateFormatItem-Gy": "y G",
	"dateFormatItem-M": "L",
	"days-standAlone-wide": [
		"Söndag",
		"Måndag",
		"Tisdag",
		"Onsdag",
		"Torsdag",
		"Fredag",
		"Lördag"
	],
	"dateFormatItem-MMMMd": "d MMMM",
	"timeFormat-medium": "HH:mm:ss",
	"field-sun-relative+0": "söndag denna vecka",
	"dateFormatItem-Hm": "HH:mm",
	"quarters-standAlone-abbr": [
		"K1",
		"K2",
		"K3",
		"K4"
	],
	"field-sun-relative+1": "söndag nästa vecka",
	"eraAbbr": [
		"f.Kr.",
		"e.Kr."
	],
	"field-minute": "Minut",
	"field-dayperiod": "fm/em",
	"days-standAlone-abbr": [
		"Sön",
		"Mån",
		"Tis",
		"Ons",
		"Tor",
		"Fre",
		"Lör"
	],
	"dateFormatItem-d": "d",
	"dateFormatItem-ms": "mm:ss",
	"quarters-format-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-day-relative+-1": "i går",
	"dateFormatItem-h": "h a",
	"dateTimeFormat-long": "{1} {0}",
	"dayPeriods-format-narrow-am": "f",
	"field-day-relative+-2": "i förrgår",
	"dateFormatItem-MMMd": "d MMM",
	"dateFormatItem-MEd": "E d/M",
	"dateTimeFormat-full": "{1} {0}",
	"field-fri-relative+0": "fredag denna vecka",
	"field-fri-relative+1": "fredag nästa vecka",
	"field-day": "Dag",
	"days-format-wide": [
		"söndag",
		"måndag",
		"tisdag",
		"onsdag",
		"torsdag",
		"fredag",
		"lördag"
	],
	"field-zone": "Tidszon",
	"dateFormatItem-y": "y",
	"months-standAlone-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"field-year-relative+-1": "i fjol",
	"field-month-relative+-1": "förra månaden",
	"dateFormatItem-hm": "h:mm a",
	"dayPeriods-format-abbr-pm": "EM",
	"days-format-abbr": [
		"sön",
		"mån",
		"tis",
		"ons",
		"tors",
		"fre",
		"lör"
	],
	"eraNames": [
		"före Kristus",
		"före västerländsk tideräkning",
		"efter Kristus",
		"västerländsk tideräkning"
	],
	"dateFormatItem-yMMMd": "d MMM y",
	"days-format-narrow": [
		"S",
		"M",
		"T",
		"O",
		"T",
		"F",
		"L"
	],
	"days-standAlone-narrow": [
		"S",
		"M",
		"T",
		"O",
		"T",
		"F",
		"L"
	],
	"dateFormatItem-MMM": "LLL",
	"field-month": "Månad",
	"field-tue-relative+0": "tisdag denna vecka",
	"field-tue-relative+1": "tisdag nästa vecka",
	"dayPeriods-format-wide-am": "fm",
	"dateFormatItem-MMMMEd": "E d MMMM",
	"dateFormatItem-EHm": "E HH:mm",
	"field-mon-relative+0": "måndag denna vecka",
	"field-mon-relative+1": "måndag nästa vecka",
	"dateFormat-short": "y-MM-dd",
	"dateFormatItem-MMd": "d/M",
	"dateFormatItem-EHms": "E HH:mm:ss",
	"dateFormatItem-Ehms": "E h:mm:ss a",
	"field-second": "Sekund",
	"field-sat-relative+-1": "lördag förra veckan",
	"dateFormatItem-yMMMEd": "E d MMM y",
	"field-sun-relative+-1": "söndag förra veckan",
	"field-month-relative+0": "denna månad",
	"field-month-relative+1": "nästa månad",
	"dateFormatItem-Ed": "E d",
	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
	"field-week": "Vecka",
	"dateFormat-medium": "d MMM y",
	"field-year-relative+0": "i år",
	"field-week-relative+-1": "förra veckan",
	"field-year-relative+1": "nästa år",
	"dayPeriods-format-narrow-pm": "e",
	"dateTimeFormat-short": "{1} {0}",
	"dateFormatItem-Hms": "HH:mm:ss",
	"dateFormatItem-hms": "h:mm:ss a",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-mon-relative+-1": "måndag förra veckan",
	"field-week-relative+0": "denna vecka",
	"field-week-relative+1": "nästa vecka"
}
//end v1.x content
);

==> dojo_1.14.2+dfsg1.orig.tar.gz: dojo-release-1.14.2-src/dojo/cldr/nls/sv/gregorian.js <==
define(
//begin v1.x content
{
	"dateFormatItem-Ehm": "E h:mm a",
	"days-standAlone-short": [
		"Sö",
		"Må",
		"Ti",
		"On",
		"To",
		"Fr",
		"Lö"
	],
	"months-format-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"field-second-relative+0": "nu",
	"quarters-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-weekday": "Veckodag",
	"dateFormatItem-yQQQ": "y QQQ",
	"dateFormatItem-yMEd": "E, y-MM-dd",
	"field-wed-relative+0": "onsdag denna vecka",
	"dateFormatItem-GyMMMEd": "E d MMM y G",
	"dateFormatItem-MMMEd": "E d MMM",
	"field-wed-relative+1": "onsdag nästa vecka",
	"eraNarrow": [
		"f.Kr.",
		"fvt",
		"e.Kr.",
		"vt"
	],
	"dateFormatItem-yMM": "y-MM",
	"field-tue-relative+-1": "tisdag förra veckan",
	"days-format-short": [
		"sö",
		"må",
		"ti",
		"on",
		"to",
		"fr",
		"lö"
	],
	"dateFormat-long": "d MMMM y",
	"field-fri-relative+-1": "fredag förra veckan",
	"field-wed-relative+-1": "onsdag förra veckan",
	"months-format-wide": [
		"januari",
		"februari",
		"mars",
		"april",
		"maj",
		"juni",
		"juli",
		"augusti",
		"september",
		"oktober",
		"november",
		"december"
	],
	"dateTimeFormat-medium": "{1} {0}",
	"dayPeriods-format-wide-pm": "em",
	"dateFormat-full": "EEEE d MMMM y",
	"field-thu-relative+-1": "torsdag förra veckan",
	"dateFormatItem-Md": "d/M",
	"dayPeriods-format-abbr-am": "FM",
	"dateFormatItem-yMd": "y-MM-dd",
	"dateFormatItem-yM": "y-MM",
	"field-era": "Era",
	"months-standAlone-wide": [
		"Januari",
		"Februari",
		"Mars",
		"April",
		"Maj",
		"Juni",
		"Juli",
		"Augusti",
		"September",
		"Oktober",
		"November",
		"December"
	],
	"timeFormat-short": "HH:mm",
	"quarters-format-wide": [
		"1:a kvartalet",
		"2:a kvartalet",
		"3:e kvartalet",
		"4:e kvartalet"
	],
	"timeFormat-long": "HH:mm:ss z",
	"dateFormatItem-yMMM": "MMM y",
	"dateFormatItem-yQQQQ": "y QQQQ",
	"field-year": "År",
	"dateFormatItem-MMdd": "dd/MM",
	"field-hour": "Timme",
	"months-format-abbr": [
		"jan.",
		"feb.",
		"mars",
		"apr.",
		"maj",
		"juni",
		"juli",
		"aug.",
		"sep.",
		"okt.",
		"nov.",
		"dec."
	],
	"field-sat-relative+0": "lördag denna vecka",
	"field-sat-relative+1": "lördag nästa vecka",
	"timeFormat-full": "'kl'. HH:mm:ss zzzz",
	"field-day-relative+0": "i dag",
	"field-day-relative+1": "i morgon",
	"field-thu-relative+0": "torsdag denna vecka",
	"dateFormatItem-GyMMMd": "d MMM y G",
	"field-day-relative+2": "i övermorgon",
	"field-thu-relative+1": "torsdag nästa vecka",
	"dateFormatItem-H": "HH",
	"months-standAlone-abbr": [
		"Jan.",
		"Feb.",
		"Mars",
		"Apr.",
		"Maj",
		"Juni",
		"Juli",
		"Aug.",
		"Sep.",
		"Okt.",
		"Nov.",
		"Dec."
	],
	"quarters-format-abbr": [
		"K1",
		"K2",
		"K3",
		"K4"
	],
	"quarters-standAlone-wide": [
		"1:a kvartalet",
		"2:a kvartalet",
		"3:e kvartalet",
		"4:e kvartalet"
	],
	"dateFormatItem-Gy": "y G",
	"dateFormatItem-M": "L",
	"days-standAlone-wide": [
		"Söndag",
		"Måndag",
		"Tisdag",
		"Onsdag",
		"Torsdag",
		"Fredag",
		"Lördag"
	],
	"dateFormatItem-MMMMd": "d MMMM",
	"timeFormat-medium": "HH:mm:ss",
	"field-sun-relative+0": "söndag denna vecka",
	"dateFormatItem-Hm": "HH:mm",
	"quarters-standAlone-abbr": [
		"K1",
		"K2",
		"K3",
		"K4"
	],
	"field-sun-relative+1": "söndag nästa vecka",
	"eraAbbr": [
		"f.Kr.",
		"e.Kr."
	],
	"field-minute": "Minut",
	"field-dayperiod": "fm/em",
	"days-standAlone-abbr": [
		"Sön",
		"Mån",
		"Tis",
		"Ons",
		"Tor",
		"Fre",
		"Lör"
	],
	"dateFormatItem-d": "d",
	"dateFormatItem-ms": "mm:ss",
	"quarters-format-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-day-relative+-1": "i går",
	"dateFormatItem-h": "h a",
	"dateTimeFormat-long": "{1} {0}",
	"dayPeriods-format-narrow-am": "f",
	"field-day-relative+-2": "i förrgår",
	"dateFormatItem-MMMd": "d MMM",
	"dateFormatItem-MEd": "E d/M",
	"dateTimeFormat-full": "{1} {0}",
	"field-fri-relative+0": "fredag denna vecka",
	"field-fri-relative+1": "fredag nästa vecka",
	"field-day": "Dag",
	"days-format-wide": [
		"söndag",
		"måndag",
		"tisdag",
		"onsdag",
		"torsdag",
		"fredag",
		"lördag"
	],
	"field-zone": "Tidszon",
	"dateFormatItem-y": "y",
	"months-standAlone-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"field-year-relative+-1": "i fjol",
	"field-month-relative+-1": "förra månaden",
	"dateFormatItem-hm": "h:mm a",
	"dayPeriods-format-abbr-pm": "EM",
	"days-format-abbr": [
		"sön",
		"mån",
		"tis",
		"ons",
		"tors",
		"fre",
		"lör"
	],
	"eraNames": [
		"före Kristus",
		"efter Kristus"
	],
	"dateFormatItem-yMMMd": "d MMM y",
	"days-format-narrow": [
		"S",
		"M",
		"T",
		"O",
		"T",
		"F",
		"L"
	],
	"days-standAlone-narrow": [
		"S",
		"M",
		"T",
		"O",
		"T",
		"F",
		"L"
	],
	"dateFormatItem-MMM": "LLL",
	"field-month": "Månad",
	"field-tue-relative+0": "tisdag denna vecka",
	"field-tue-relative+1": "tisdag nästa vecka",
	"dayPeriods-format-wide-am": "fm",
	"dateFormatItem-MMMMEd": "E d MMMM",
	"dateFormatItem-EHm": "E HH:mm",
	"field-mon-relative+0": "måndag denna vecka",
	"field-mon-relative+1": "måndag nästa vecka",
	"dateFormat-short": "y-MM-dd",
	"dateFormatItem-MMd": "d/M",
	"dateFormatItem-EHms": "E HH:mm:ss",
	"dateFormatItem-Ehms": "E h:mm:ss a",
	"field-second": "Sekund",
	"field-sat-relative+-1": "lördag förra veckan",
	"dateFormatItem-yMMMEd": "E d MMM y",
	"field-sun-relative+-1": "söndag förra veckan",
	"field-month-relative+0": "denna månad",
	"field-month-relative+1": "nästa månad",
	"dateFormatItem-Ed": "E d",
	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
	"field-week": "Vecka",
	"dateFormat-medium": "d MMM y",
	"field-year-relative+0": "i år",
	"field-week-relative+-1": "förra veckan",
	"field-year-relative+1": "nästa år",
	"dayPeriods-format-narrow-pm": "e",
	"dateTimeFormat-short": "{1} {0}",
	"dateFormatItem-Hms": "HH:mm:ss",
	"dateFormatItem-hms": "h:mm:ss a",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-mon-relative+-1": "måndag förra veckan",
	"field-week-relative+0": "denna vecka",
	"field-week-relative+1": "nästa vecka"
}
//end v1.x content
);
